@@ -1,11 +1,15 @@
-import urllib
+import six
 
 from django.core.cache import cache
 from django.core.exceptions import ImproperlyConfigured
 from django.utils.functional import SimpleLazyObject
+from django.utils.http import urlquote
 
-from queued_storage.conf import settings
-from queued_storage.utils import import_attribute
+from .conf import settings
+from .utils import import_attribute, django_version
+
+if django_version()[1] >= 7:
+    from django.utils.deconstruct import deconstructible
 
 
 class LazyBackend(SimpleLazyObject):
@@ -42,7 +46,7 @@ class QueuedStorage(object):
     #: The options of the local storage class, defined as a dictionary.
     local_options = None
 
-    #: The local storage class to use. A dotted path (e.g.
+    #: The remote storage class to use. A dotted path (e.g.
     #: ``'django.core.files.storage.FileSystemStorage'``).
     remote = None
 
@@ -58,7 +62,6 @@ class QueuedStorage(object):
     #: location automatically, but instead requires manual intervention by the
     #: user with the :meth:`~queued_storage.backends.QueuedStorage.transfer`
     #: method.
-    #:
     delayed = False
 
     #: The cache key prefix to use when saving the which storage backend
@@ -91,8 +94,8 @@ class QueuedStorage(object):
         if backend is None:  # pragma: no cover
             raise ImproperlyConfigured("The QueuedStorage class '%s' "
                                        "doesn't define a needed backend." %
-                                       (self, backend))
-        if not isinstance(backend, basestring):
+                                       (self))
+        if not isinstance(backend, six.string_types):
             raise ImproperlyConfigured("The QueuedStorage class '%s' "
                                        "requires its backends to be "
                                        "specified as dotted import paths "
@@ -126,7 +129,7 @@ class QueuedStorage(object):
         :type name: str
         :rtype: str
         """
-        return '%s_%s' % (self.cache_prefix, urllib.quote(name))
+        return '%s_%s' % (self.cache_prefix, urlquote(name))
 
     def using_local(self, name):
         """
@@ -178,6 +181,10 @@ class QueuedStorage(object):
         """
         cache_key = self.get_cache_key(name)
         cache.set(cache_key, False)
+
+        # Use a name that is available on both the local and remote storage
+        # systems and save locally.
+        name = self.get_available_name(name)
         name = self.local.save(name, content)
 
         # Pass on the cache key to prevent duplicate cache key creation,
@@ -216,14 +223,19 @@ class QueuedStorage(object):
 
     def get_available_name(self, name):
         """
-        Returns a filename that's free on the current storage system, and
-        available for new content to be written to.
+        Returns a filename that's free on both the local and remote storage
+        systems, and available for new content to be written to.
 
         :param name: file name
         :type name: str
         :rtype: str
         """
-        return self.get_storage(name).get_available_name(name)
+        local_available_name = self.local.get_available_name(name)
+        remote_available_name = self.remote.get_available_name(name)
+
+        if remote_available_name > local_available_name:
+            return remote_available_name
+        return local_available_name
 
     def path(self, name):
         """
@@ -322,6 +334,8 @@ class QueuedStorage(object):
         :rtype: :class:`~python:datetime.datetime`
         """
         return self.get_storage(name).modified_time(name)
+if django_version()[1] >= 7:
+    QueuedStorage = deconstructible(QueuedStorage)
 
 
 class QueuedFileSystemStorage(QueuedStorage):
