@@ -1,10 +1,17 @@
 from django.core.cache import cache
 
 from celery.task import Task
+try:
+    from celery.utils.log import get_task_logger
+except ImportError:
+    from celery.log import get_task_logger
 
-from queued_storage.conf import settings
-from queued_storage.signals import file_transferred
-from queued_storage.utils import import_attribute
+
+from .conf import settings
+from .signals import file_transferred
+from .utils import import_attribute
+
+logger = get_task_logger(name=__name__)
 
 
 class Transfer(Task):
@@ -107,8 +114,7 @@ class Transfer(Task):
         try:
             remote.save(name, local.open(name))
             return True
-        except Exception, e:
-            logger = self.get_logger(**kwargs)
+        except Exception as e:
             logger.error("Unable to save '%s' to remote storage. "
                          "About to retry." % name)
             logger.exception(e)
