@@ -4,5 +4,7 @@ from queued_storage.fields import QueuedFileField
 
 
 class TestModel(models.Model):
-    file = models.FileField(upload_to='test', null=True)
+    testfile = models.FileField(upload_to='test', null=True)
     remote = QueuedFileField(upload_to='test', null=True)
+
+    retried = False
