@@ -1,6 +1,8 @@
 from queued_storage.tasks import Transfer
 from queued_storage.utils import import_attribute
 
+from .models import TestModel
+
 
 def test_task(name, cache_key,
               local_path, remote_path,
@@ -19,3 +21,12 @@ test_task.delay = delay
 class NoneReturningTask(Transfer):
     def transfer(self, *args, **kwargs):
         return None
+
+
+class RetryingTask(Transfer):
+    def transfer(self, *args, **kwargs):
+        if TestModel.retried:
+            return True
+        else:
+            TestModel.retried = True
+            return False
